@@ -529,7 +529,14 @@ public class FormatData_ru extends ListResourceBundle {
             { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM yyyy\u202f'\u0433'. GGGG",
+                    "d MMMM yyyy\u202f'\u0433'. GGGG",
+                    "d MMM y\u202f'\u0433'. GGGG",
+                    "dd.MM.y GGGG",
+                }
+            },
             { "japanese.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
